"use strict";
/**
 * Exposes common HTTP errors with a preconfigured `statusCode` for convenience.
 * This does not mean you have to use HTTP to use them, it's just that
 * HTTP has already defined a nice set of common error types, and tacking
 * on the HTTP status code makes it easier to consume in HTTP apps.
 */
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var make_error_class_1 = require("./make-error-class");
/**
 * Creates a `BadRequest` error.
 */
var BadRequest = /** @class */ (function (_super) {
    tslib_1.__extends(BadRequest, _super);
    function BadRequest() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return BadRequest;
}(MakeHttpError(400, 'Bad Request')));
exports.BadRequest = BadRequest;
/**
 * Creates a `NotAuthenticated` error.
 */
var NotAuthenticated = /** @class */ (function (_super) {
    tslib_1.__extends(NotAuthenticated, _super);
    function NotAuthenticated() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NotAuthenticated;
}(MakeHttpError(401, 'Not Authenticated')));
exports.NotAuthenticated = NotAuthenticated;
/**
 * Creates a `PaymentError` error.
 */
var PaymentError = /** @class */ (function (_super) {
    tslib_1.__extends(PaymentError, _super);
    function PaymentError() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return PaymentError;
}(MakeHttpError(402, 'Payment Error')));
exports.PaymentError = PaymentError;
/**
 * Creates a `Forbidden` error.
 */
var Forbidden = /** @class */ (function (_super) {
    tslib_1.__extends(Forbidden, _super);
    function Forbidden() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Forbidden;
}(MakeHttpError(403, 'Forbidden')));
exports.Forbidden = Forbidden;
/**
 * Creates a `NotFound` error.
 */
var NotFound = /** @class */ (function (_super) {
    tslib_1.__extends(NotFound, _super);
    function NotFound() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NotFound;
}(MakeHttpError(404, 'Not Found')));
exports.NotFound = NotFound;
/**
 * Creates a `MethodNotAllowed` error.
 */
var MethodNotAllowed = /** @class */ (function (_super) {
    tslib_1.__extends(MethodNotAllowed, _super);
    function MethodNotAllowed() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return MethodNotAllowed;
}(MakeHttpError(405, 'Method Not Allowed')));
exports.MethodNotAllowed = MethodNotAllowed;
/**
 * Creates a `NotAcceptable` error.
 */
var NotAcceptable = /** @class */ (function (_super) {
    tslib_1.__extends(NotAcceptable, _super);
    function NotAcceptable() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NotAcceptable;
}(MakeHttpError(406, 'Not Acceptable')));
exports.NotAcceptable = NotAcceptable;
/**
 * Creates a `Timeout` error.
 */
var Timeout = /** @class */ (function (_super) {
    tslib_1.__extends(Timeout, _super);
    function Timeout() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Timeout;
}(MakeHttpError(408, 'Timeout')));
exports.Timeout = Timeout;
/**
 * Creates a `Conflict` error.
 */
var Conflict = /** @class */ (function (_super) {
    tslib_1.__extends(Conflict, _super);
    function Conflict() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Conflict;
}(MakeHttpError(409, 'Conflict')));
exports.Conflict = Conflict;
/**
 * Creates a `LengthRequired` error.
 */
var LengthRequired = /** @class */ (function (_super) {
    tslib_1.__extends(LengthRequired, _super);
    function LengthRequired() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return LengthRequired;
}(MakeHttpError(411, 'Length Required')));
exports.LengthRequired = LengthRequired;
/**
 * Creates a `Unprocessable` error.
 */
var Unprocessable = /** @class */ (function (_super) {
    tslib_1.__extends(Unprocessable, _super);
    function Unprocessable() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Unprocessable;
}(MakeHttpError(422, 'Unprocessable')));
exports.Unprocessable = Unprocessable;
/**
 * Creates a `TooManyRequests` error.
 */
var TooManyRequests = /** @class */ (function (_super) {
    tslib_1.__extends(TooManyRequests, _super);
    function TooManyRequests() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return TooManyRequests;
}(MakeHttpError(429, 'Too Many Requests')));
exports.TooManyRequests = TooManyRequests;
/**
 * Creates a `GeneralError` error.
 */
var GeneralError = /** @class */ (function (_super) {
    tslib_1.__extends(GeneralError, _super);
    function GeneralError() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return GeneralError;
}(MakeHttpError(500, 'General Error')));
exports.GeneralError = GeneralError;
/**
 * Creates a `NotImplemented` error.
 */
var NotImplemented = /** @class */ (function (_super) {
    tslib_1.__extends(NotImplemented, _super);
    function NotImplemented() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NotImplemented;
}(MakeHttpError(501, 'Not Implemented')));
exports.NotImplemented = NotImplemented;
/**
 * Creates a `BadGateway` error.
 */
var BadGateway = /** @class */ (function (_super) {
    tslib_1.__extends(BadGateway, _super);
    function BadGateway() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return BadGateway;
}(MakeHttpError(502, 'Bad Gateway')));
exports.BadGateway = BadGateway;
/**
 * Creates a `Unavailable` error.
 */
var Unavailable = /** @class */ (function (_super) {
    tslib_1.__extends(Unavailable, _super);
    function Unavailable() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Unavailable;
}(MakeHttpError(503, 'Unavailable')));
exports.Unavailable = Unavailable;
/**
 * Bulds a HTTP status code based error class.
 *
 * @private
 * @param statusCode The status code.
 * @param message The message.
 */
function MakeHttpError(statusCode, message) {
    return make_error_class_1.MakeErrorClass(message, { statusCode: statusCode });
}
//# sourceMappingURL=http.js.map