"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var make_error_1 = require("make-error");
/**
 * Base error class.
 */
var BaseError = /** @class */ (function (_super) {
    tslib_1.__extends(BaseError, _super);
    /**
     * Initializes a new instance of the error.
     *
     * @param message Error message.
     * @param attrs Attributes to merge onto the instance.
     */
    function BaseError(message, attrs) {
        var _this = _super.call(this, message) || this;
        Object.assign(_this, attrs);
        return _this;
    }
    /**
     * Preconfigures an `assert` function.
     *
     * @example
     *   promise.then(MyError.makeAssert('Stuff was not found'))
     */
    BaseError.makeAssert = function (message) {
        var _this = this;
        return function (value) { return _this.assert(value, message); };
    };
    /**
     * If `data` is falsy, throws the error with the specified message.
     *
     * @param data The data to check.
     * @param message The message to construct the error with.
     */
    BaseError.assert = function (data, message) {
        if (!data) {
            throw new this(message);
        }
        return data;
    };
    /**
     * Default toJSON implementation.
     */
    BaseError.prototype.toJSON = function () {
        var result = {
            stack: this.stack,
            message: this.message
        };
        for (var prop in this) {
            var val = this[prop];
            if (typeof val !== 'function') {
                result[prop] = val;
            }
        }
        return result;
    };
    return BaseError;
}(make_error_1.BaseError));
exports.BaseError = BaseError;
/**
 * Makes a new error class preconfigured with the specified settings,
 * as well as some extra methods for assertions.
 *
 * @param defaultMessage The default error message.
 * @param defaultAttrs The default attributes for creating new instances.
 */
function MakeErrorClass(defaultMessage, defaultAttrs) {
    if (defaultMessage === void 0) { defaultMessage = 'An error occured'; }
    var ConfiguredError = /** @class */ (function (_super) {
        tslib_1.__extends(ConfiguredError, _super);
        function ConfiguredError(message, attrs) {
            var _this = this;
            // tslint:disable-next-line
            message = message === null || message === undefined ? defaultMessage : message;
            // istanbul ignore next: TS <-> Istanbul issue
            _this = _super.call(this, message, Object.assign({}, defaultAttrs, attrs)) || this;
            return _this;
        }
        return ConfiguredError;
    }(BaseError));
    return ConfiguredError;
}
exports.MakeErrorClass = MakeErrorClass;
//# sourceMappingURL=make-error-class.js.map